@@ -59,10 +59,13 @@ def fetch(datestring, today):
     user = g.get_user()
     repo = user.get_repo(get_remote_name())
     if today and datestring == '':
-        now = datetime.now()
-        datestring = now.strftime("%Y/%m/%d")
+        datestring = datetime.now().strftime("%Y/%m/%d")
     try:
-        contents = repo.get_contents("entries/" + datestring)
+        if datestring == '':
+            contents = repo.get_contents("entries")
+        else:
+            contents = repo.get_contents("entries/" + datestring)
+
         # Count number of files; This takes about half a second for 20 files
         file_count = 0
         while contents:
@@ -75,7 +78,11 @@ def fetch(datestring, today):
         # initialize progress bar
         pbar = tqdm(total=file_count)
         # Get file contents and add to output_lines
-        contents = repo.get_contents("entries/" + datestring)
+        if datestring == '':
+            contents = repo.get_contents("entries")
+        else:
+            contents = repo.get_contents("entries/" + datestring)
+
         while contents:
             file_content = contents.pop(0)
             if file_content.type == "dir":
@@ -88,7 +95,8 @@ def fetch(datestring, today):
                 pbar.update(1)
         output = '\n'.join(output_lines)
         pbar.close()
-    except Exception:
+    except Exception as ex:
+        print(ex)
         output = "No entries found for specified day(s)"
     print(output)
 
@@ -112,7 +120,7 @@ def make_readme(local):
         if file_content.type == "dir":
             contents.extend(repo.get_contents(file_content.path))
         else:
-            this_date = (file_content.path)[8:-13]
+            this_date = (file_content.path)[8:18]
             # The 2 lines below remove files that are in the root directory, which are not logs
             if (file_content.path)[7] != '/':
                 continue
